simd_carryless_mul

Function simd_carryless_mul 

pub unsafe fn simd_carryless_mul<T>(a: T, b: T) -> T
🔬This is a nightly-only experimental API. (core_intrinsics)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Compute the carry-less product.

This is similar to long multiplication except that the carry is discarded.

This operation can be used to model multiplication in GF(2)[X], the polynomial ring over GF(2).

T must be a vector of integers.