pub const unsafe fn simd_insert<T, U>(x: T, idx: u32, val: U) -> T🔬This is a nightly-only experimental API. (
core_intrinsics)This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Inserts an element into a vector, returning the updated vector.
T must be a vector with element type U, and idx must be const.
Safety
idx must be in-bounds of the vector.