simd_le

Function simd_le 

pub const unsafe fn simd_le<T, U>(x: T, y: T) -> U
🔬This is a nightly-only experimental API. (core_intrinsics)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Tests if x is less than or equal to y, elementwise.

T must be a vector of integers or floats.

U must be a vector of integers with the same number of elements and element size as T.

Returns 0 for false and !0 for true.