pub const unsafe fn simd_shr<T>(lhs: T, rhs: T) -> T🔬This is a nightly-only experimental API. (
core_intrinsics)This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Shifts vector right elementwise, with UB on overflow.
T must be a vector of integers.
Shifts lhs right by rhs, shifting in sign bits for signed types.
Safety
Each element of rhs must be less than <int>::BITS.