simd_splat

Function simd_splat 

pub const unsafe fn simd_splat<T, U>(value: U) -> T
🔬This is a nightly-only experimental API. (core_intrinsics)
This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Creates a vector where every lane has the provided value.

T must be a vector with element type U.