pub const unsafe fn simd_shl<T>(lhs: T, rhs: T) -> T🔬This is a nightly-only experimental API. (
core_intrinsics)This item is validated for IEC 61508 (SIL 2) and ISO 26262 (ASIL B).
Shifts vector left elementwise, with UB on overflow.
Shifts lhs left by rhs, shifting in sign bits for signed types.
T must be a vector of integers.
Safety
Each element of rhs must be less than <int>::BITS.